@@ -48,10 +48,7 @@ class Class1:
     def __init__(
         self,
     ):
-        super(
-            Class1,
-            self,
-        ).__init__()
+        super().__init__()
         self.x = 2
 
     def method3(
